#!/bin/sh

##  =()<. @<_PATH_SHELLVARS>@>()=
. /home/news/innshellvars

YYMMDD=`date +%y%m%d`
HHMM=`date +%H%M`
NOW=${YYMMDD}$HHMM

exec > $MOST_LOGS/newsflow.log 2>&1

PROGNAME=`basename $0`
echo Beginning $PROGNAME at `date`

# Don't change the feedname unless you change flowproc.pl.
FEEDNAME=news..flow
FLOWWORK=$BATCH/flow/work
FLOWDAY=$BATCH/flow/day

# Change to the batch directory and try to get the lock for this script.
cd $BATCH
LOCK=${LOCKS}/LOCK.${PROGNAME}
trap "rm -f ${LOCK} ; exit 1" 1 2 3 15
shlock -p $$ -f ${LOCK} || {
    exit
}

# Flush the feed.  Don't worry about the ctlinnd hanging because if it
# does, you've got other problems.  When you fix those, this script will
# recover.  It just means that the next time this script runs, it will
# just have a bigger batch.
echo Flushing queue
mv $FEEDNAME $FEEDNAME.$NOW
ctlinnd -s flush $FEEDNAME
mv $FEEDNAME.* $FLOWWORK

# Run flowproc.pl to convert the feed data into raw data files.  If the
# system dies before flowproc.pl finishes, it's not a problem.  It will
# just create the same raw data files.
echo Running flowproc
cd $FLOWWORK
FEEDDATA=`ls | grep '^news\.\.flow\.[0-9][0-9]*$'`
[ -n "$FEEDDATA" ] && {
    flowproc.pl $FEEDDATA || {
	echo flowproc.pl failed | $MAILCMD -s "news flow" $NEWSMASTER
	rm -f $LOCK
	exit 1
    }
}

# Check if any daily files are left over from a previous run.  If there
# are, delete the corresponding hourly files and move the daily files
# to the flowday directory.
echo Checking artsday
DAYCOUNT=`ls | grep "^artsday\." | wc -l`
while [ $DAYCOUNT -gt 0 ]
do
    DAY=`ls | grep "^artsday\." | head -1 | awk -F. '{print $2}'`
    rm -f artshour.${DAY}.*
    mv artsday.$DAY $FLOWDAY
    DAYCOUNT=`ls | grep "^artsday\." | wc -l`
done

echo Checking fromday
DAYCOUNT=`ls | grep "^fromday\." | wc -l`
while [ $DAYCOUNT -gt 0 ]
do
    DAY=`ls | grep "^fromday\." | head -1 | awk -F. '{print $2}'`
    rm -f fromhour.${DAY}.*
    flowfromrept.pl fromday.$DAY | $MAILCMD -s "News Flow Report" $NEWSMASTER
    mv fromday.$DAY $FLOWDAY
    DAYCOUNT=`ls | grep "^fromday\." | wc -l`
done

# If there is more than one day of hourly files, process all but the
# hour files for today.  This will happen on the first run after
# midnight.
#artshour.960229.1800.9902291900
ARTSHOUR=`ls | grep "^artshour\." | grep -v "^artshour\.$YYMMDD"`
[ -n "$ARTSHOUR" ] && {
    flowarts.pl $ARTSHOUR || {
	echo flowarts.pl failed | $MAILCMD -s "news flow" $NEWSMASTER
	rm -f $LOCK
	exit 1
    }
}

#fromhour.960229.1800.9902291900
FROMHOUR=`ls | grep "^fromhour\." | grep -v "^fromhour\.$YYMMDD"`
[ -n "$FROMHOUR" ] && {
    flowfrom.pl $FROMHOUR || {
	echo flowfrom.pl failed | $MAILCMD -s "news flow" $NEWSMASTER
	rm -f $LOCK
	exit 1
    }
}

rm -f $LOCK
